==> dagr-web-0.4.2-sources.jar: net/aequologica/neo/dagr/jaxrs/ResourceTravis.java <==
package net.aequologica.neo.dagr.jaxrs;

import javax.inject.Inject;
import javax.json.JsonObject;
import javax.ws.rs.Consumes;
import javax.ws.rs.FormParam;
import javax.ws.rs.POST;
import javax.ws.rs.core.Response;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import net.aequologica.neo.dagr.bus.Bus;
import net.aequologica.neo.dagr.bus.BusEvent;
import net.aequologica.neo.dagr.model.Dag.Node;

@javax.ws.rs.Path("/travis")
public class ResourceTravis extends AbstractResource {
    
    final static Logger log = LoggerFactory.getLogger("net.aequologica.neo.dagr.jaxrs");
    
    @Inject private Bus<Node> bus;
    
    @POST
    @javax.ws.rs.Path("notifications")
    @Consumes("application/x-www-form-urlencoded")
    public Response receiveNotification(@FormParam("payload") String payload) throws Exception {
        
        try {
            log.debug("[travis] payload: {}", payload);
            System.out.println("[travis] payload: "+ payload.replace("\n", "").replace("\r", ""));
        
            // massage travis payload
            JsonObject travisPayload = mapper.readValue(payload, JsonObject.class);
            if (travisPayload == null) {
                Response.serverError().entity("failed to parse payload from [" + payload + "]").build();
            }
            
            String name = null;
            String owner_name = null;
            JsonObject repository = travisPayload.getJsonObject("repository");
            if (repository != null) {
                name = repository.getString("name");
                owner_name = repository.getString("owner_name");
            }
            final String branch = travisPayload.getString("branch");
            final int    status = travisPayload.getInt("status");
        
            if (name != null && branch != null) {
                BusEvent.Type type = (status == 0 ? BusEvent.Type.TRAVIS_OK : BusEvent.Type.TRAVIS_ERROR);
                
                String owner_name_name = (owner_name != null && !owner_name.isEmpty() ? owner_name + '/' + name : name);
                
                log.debug("[travis] sending event {}, owner_name/name='{}', branch='{}' to the bus", type, owner_name_name, branch);
                System.out.println("[travis] sending event "+type+", owner_name/name='"+owner_name_name+"', branch='"+branch+"' to the bus");
                
                // balance dans le bus
                bus.send(type, owner_name_name, branch);
            }
        
            return Response.noContent().build();
        } catch (Exception e) {
            log.error("[bus] exception {} logged and re-thrown", e.getMessage());
            System.err.println("[bus] exception " + e.getMessage() + "logged and re-thrown");
            throw e;
        } finally {
        }
    }
    
}

==> dagr-web-0.5.0-sources.jar: net/aequologica/neo/dagr/jaxrs/ResourceTravis.java <==
package net.aequologica.neo.dagr.jaxrs;

import javax.inject.Inject;
import javax.json.JsonObject;
import javax.ws.rs.Consumes;
import javax.ws.rs.FormParam;
import javax.ws.rs.POST;
import javax.ws.rs.core.Response;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import net.aequologica.neo.dagr.bus.Bus;
import net.aequologica.neo.dagr.bus.BusEvent;
import net.aequologica.neo.dagr.model.Dag.Node;

@javax.ws.rs.Path("/travis")
public class ResourceTravis extends AbstractResource {
    
    final static Logger log = LoggerFactory.getLogger(ResourceTravis.class);
    
    @Inject private Bus<Node> bus;
    
    @POST
    @javax.ws.rs.Path("notifications")
    @Consumes("application/x-www-form-urlencoded")
    public Response receiveNotification(@FormParam("payload") String payload) throws Exception {
        
        try {
            log.debug("[travis] payload: {}", payload);
            System.out.println("[travis] payload: "+ payload.replace("\n", "").replace("\r", ""));
        
            // massage travis payload
            JsonObject travisPayload = mapper.readValue(payload, JsonObject.class);
            if (travisPayload == null) {
                Response.serverError().entity("failed to parse payload from [" + payload + "]").build();
            }
            
            String name = null;
            String owner_name = null;
            JsonObject repository = travisPayload.getJsonObject("repository");
            if (repository != null) {
                name = repository.getString("name");
                owner_name = repository.getString("owner_name");
            }
            final String branch = travisPayload.getString("branch");
            final int    status = travisPayload.getInt("status");
        
            if (name != null && branch != null) {
                BusEvent.Type type = (status == 0 ? BusEvent.Type.TRAVIS_OK : BusEvent.Type.TRAVIS_ERROR);
                
                String owner_name_name = (owner_name != null && !owner_name.isEmpty() ? owner_name + '/' + name : name);
                
                log.debug("[travis] sending event {}, owner_name/name='{}', branch='{}' to the bus", type, owner_name_name, branch);
                System.out.println("[travis] sending event "+type+", owner_name/name='"+owner_name_name+"', branch='"+branch+"' to the bus");
                
                // balance dans le bus
                bus.send(type, owner_name_name, branch);
            }
        
            return Response.noContent().build();
        } catch (Exception e) {
            log.error("[bus] exception {} logged and re-thrown", e.getMessage());
            System.err.println("[bus] exception " + e.getMessage() + "logged and re-thrown");
            throw e;
        } finally {
        }
    }
    
}
